@@ -7,13 +7,10 @@ from a28 import __version__, account, api, package, system
 
 def build_parser():
     """Build the argument for the cli."""
-    parser = argparse.ArgumentParser(
-        'a28',
-        description='Area28 development kit'
-    )
-    app = '%(prog)s version ' + __version__
-    parser.add_argument('-v', '--version', action='version', version=app)
-    sub = parser.add_subparsers(dest='action', required=True, help='actions')
+    parser = argparse.ArgumentParser("a28", description="Area28 development kit")
+    app = "%(prog)s version " + __version__
+    parser.add_argument("-v", "--version", action="version", version=app)
+    sub = parser.add_subparsers(dest="action", required=True, help="actions")
 
     api.cli_options(sub)
     package.cli_options(sub)
