@@ -7,20 +7,20 @@ from tests.conftest import Helpers
 
 def test_a28_system_no_param(helpers: Helpers) -> None:
     """Test execution of system sub argument without parameters."""
-    command = ['system']
-    expect = 'usage: a28 system [-h] (--environment {prod,staging,dev}'
+    command = ["system"]
+    expect = "usage: a28 system [-h] (--environment {prod,staging,dev,sit}"
 
     output, raise_type, exit_code = helpers.execute_error(command)
 
     assert raise_type == SystemExit
     assert exit_code == 2
-    assert output[0:len(expect)] == expect
+    assert output[0 : len(expect)] == expect
 
 
 def test_a28_exists_no_param_no_config(helpers: Helpers, tmp_path: Path):
     """Test execution of system exists without config."""
-    command = ['system', '-a', 'exists']
-    config_path = tmp_path / 'config_path'
+    command = ["system", "-a", "exists"]
+    config_path = tmp_path / "config_path"
     expect = f'No configuration exists at "{config_path}".'
     output, raise_type, exit_code = helpers.execute(command, config_path)
 
@@ -31,8 +31,8 @@ def test_a28_exists_no_param_no_config(helpers: Helpers, tmp_path: Path):
 
 def test_a28_exists_no_param_config(helpers: Helpers, tmp_path: Path) -> None:
     """Test execution of system sub argument without parameters."""
-    command = ['system', '-a', 'exists']
-    config_path = tmp_path / 'config_path'
+    command = ["system", "-a", "exists"]
+    config_path = tmp_path / "config_path"
     expect = f'Configuration exists at "{config_path}".'
     config_path.mkdir()
     output, raise_type, exit_code = helpers.execute(command, config_path)
@@ -44,8 +44,8 @@ def test_a28_exists_no_param_config(helpers: Helpers, tmp_path: Path) -> None:
 
 def test_a28_clean_no_param_no_config(helpers: Helpers, tmp_path: Path):
     """Test execution of system clean without config."""
-    command = ['system', '-a', 'clean', '-f']
-    config_path = tmp_path / 'config_path'
+    command = ["system", "-a", "clean", "-f"]
+    config_path = tmp_path / "config_path"
     expect = f'No configuration to clean at "{config_path}".'
     output, raise_type, exit_code = helpers.execute(command, config_path)
 
@@ -56,9 +56,9 @@ def test_a28_clean_no_param_no_config(helpers: Helpers, tmp_path: Path):
 
 def test_a28_clean_no_param_config(helpers: Helpers, tmp_path: Path) -> None:
     """Test execution of system sub argument without parameters."""
-    command = ['system', '-a', 'clean', '-f']
-    config_path = tmp_path / 'config_path'
-    expect = f'Deleted all files and directories in {config_path}'
+    command = ["system", "-a", "clean", "-f"]
+    config_path = tmp_path / "config_path"
+    expect = f"Deleted all files and directories in {config_path}"
     config_path.mkdir()
     output, raise_type, exit_code = helpers.execute(command, config_path)
 
@@ -69,8 +69,8 @@ def test_a28_clean_no_param_config(helpers: Helpers, tmp_path: Path) -> None:
 
 def test_a28_path_minimal_dev(helpers: Helpers, tmp_path: Path) -> None:
     """Test execution of system sub argument without parameters."""
-    command = ['system', '-e=dev', 'path', '--minimal']
-    expect = tmp_path / 'dev'
+    command = ["system", "-e=dev", "path", "--minimal"]
+    expect = tmp_path / "dev"
 
     output, raise_type, exit_code = helpers.execute(command, tmp_path)
 
@@ -81,8 +81,8 @@ def test_a28_path_minimal_dev(helpers: Helpers, tmp_path: Path) -> None:
 
 def test_a28_path_minimal_prod(helpers: Helpers, tmp_path: Path) -> None:
     """Test execution of system sub argument without parameters."""
-    command = ['system', '-e=prod', 'path', '--minimal']
-    expect = tmp_path / 'prod'
+    command = ["system", "-e=prod", "path", "--minimal"]
+    expect = tmp_path / "prod"
 
     output, raise_type, exit_code = helpers.execute(command, tmp_path)
 
@@ -93,7 +93,7 @@ def test_a28_path_minimal_prod(helpers: Helpers, tmp_path: Path) -> None:
 
 def test_a28_path_minimal_all(helpers: Helpers, tmp_path: Path) -> None:
     """Test execution of system sub argument with all parameter."""
-    command = ['system', '--all', 'path', '--minimal']
+    command = ["system", "--all", "path", "--minimal"]
     expect = tmp_path
 
     output, raise_type, exit_code = helpers.execute(command, tmp_path)
@@ -105,7 +105,7 @@ def test_a28_path_minimal_all(helpers: Helpers, tmp_path: Path) -> None:
 
 def test_a28_path_no_minimal(helpers: Helpers, tmp_path: Path) -> None:
     """Test execution of system sub argument without minimal."""
-    command = ['system', '--all', 'path']
+    command = ["system", "--all", "path"]
     expect = f'Configuration path set to "{tmp_path.resolve()}".'
     output, raise_type, exit_code = helpers.execute(command, tmp_path)
 
